@@ -15,7 +15,7 @@ from loguru import logger
 from tqdm import tqdm
 
 from skit_labels import constants as const
-from skit_labels.db import Job, SqliteDatabase
+from skit_labels.db import Database, Job, SqliteDatabase
 
 
 def batch_gen(source, n=100):
@@ -49,20 +49,17 @@ def download_dataset(
     host: Optional[str] = None,
     port: Optional[Union[int, str]] = None,
 ) -> Tuple[SqliteDatabase, str, str]:
+    database = Database(user=user, password=password, host=host, port=port)
     job = Job(
         int(job_id),
         task_type=task_type,
         tz=timezone,
         start_date=start_date,
         end_date=end_date,
-        db=db,
-        user=user,
-        password=password,
-        host=host,
-        port=port,
+        database=database
     )
-    describe_dataset(job_id)
-    stat_dataset(job_id)
+    describe_dataset(job_id, database=database)
+    stat_dataset(job_id, database=database)
 
     _, temp_filepath = tempfile.mkstemp(suffix=const.OUTPUT_FORMAT__SQLITE)
     sdb = SqliteDatabase(temp_filepath)
@@ -100,6 +97,7 @@ def sdb2df(sdb: SqliteDatabase, job_id: str) -> str:
 def describe_dataset(
     job_id: Optional[int] = None,
     job: Optional[Job] = None,
+    database: Optional[Database] = None,
     db: Optional[str] = None,
     user: Optional[str] = None,
     password: Optional[str] = None,
@@ -108,6 +106,7 @@ def describe_dataset(
 ) -> str:
     return job or Job(
         int(job_id),
+        database=database,
         db=db,
         user=user,
         password=password,
@@ -121,6 +120,7 @@ def stat_dataset(
     job: Optional[Job] = None,
     start_date: Optional[str] = None,
     end_date: Optional[str] = None,
+    database: Optional[Database] = None,
     db: Optional[str] = None,
     user: Optional[str] = None,
     password: Optional[str] = None,
@@ -131,6 +131,7 @@ def stat_dataset(
         int(job_id),
         start_date=start_date,
         end_date=end_date,
+        database=database,
         db=db,
         user=user,
         password=password,
